@@ -32,10 +32,4 @@ xa_api_reg_const_uint (xstr p_name, xuint p_value);
 xvoid
 xa_api_reg_fnct (xstr p_name, xptr p_fnct, xstr p_rettype, ...);
 
-xvoid
-xa_api_reg_class (xstr p_name, ...);
-
-xvoid
-xa_api_reg_native_class (xstr p_name, ...);
-
 #endif
