@@ -22,11 +22,8 @@
 #ifndef __XL_COMPILER_H_
 #define __XL_COMPILER_H_
 
-#include <xdefs.h>
-#include <xobject.h>
-#include <xstring.h>
+#include <xldefs.h>
 #include <xzone.h>
-#include <xlexpr.h>
 
 xvoid
 xl_compiler_compile (XLExpr* p_expr, XZone* p_code);
